All Classes and Interfaces

Class
Description
Represents a single entry in a list (or array) of DataSync agents when you call the ListAgents operation.
 
 
An AWS Arn.
 
 
 
 
The shared access signature (SAS) configuration that allows DataSync to access your Microsoft Azure Blob Storage.
 
 
CancelTaskExecutionRequest
 
 
 
Specifies configuration information for a DataSync-managed secret, such as an authentication token, secret key, password, or Kerberos keytab that DataSync uses to access a specific storage location, with a customer-managed KMS key.
 
CreateAgentRequest
 
CreateAgentResponse
 
 
 
 
 
CreateLocationEfsRequest
 
CreateLocationEfs
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
CreateLocationNfsRequest
 
CreateLocationNfsResponse
 
CreateLocationObjectStorageRequest
 
CreateLocationObjectStorageResponse
 
CreateLocationS3Request
 
CreateLocationS3Response
 
CreateLocationSmbRequest
 
CreateLocationSmbResponse
 
CreateTaskRequest
 
CreateTaskResponse
 
Specifies configuration information for a customer-managed Secrets Manager secret where a storage location credentials is stored in Secrets Manager as plain text (for authentication token, secret key, or password) or as binary (for Kerberos keytab).
 
Service client for accessing DataSync asynchronously.
A builder for creating an instance of DataSyncAsyncClient.
 
The parameters object used to resolve the auth schemes for the DataSync service.
A builder for a DataSyncAuthSchemeParams.
An auth scheme provider for DataSync service.
This includes configuration specific to DataSync that is supported by both DataSyncClientBuilder and DataSyncAsyncClientBuilder.
Service client for accessing DataSync.
A builder for creating an instance of DataSyncClient.
 
The parameters object used to resolve an endpoint for the DataSync service.
 
An endpoint provider for DataSync.
 
 
 
 
 
 
 
 
 
 
 
 
Class to expose the service client settings to the user.
A builder for creating a DataSyncServiceClientConfiguration
 
 
 
 
 
 
DeleteAgentRequest
 
 
 
DeleteLocation
 
 
 
DeleteTask
 
 
 
DescribeAgent
 
DescribeAgentResponse
 
 
 
 
 
DescribeLocationEfsRequest
 
DescribeLocationEfsResponse
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
DescribeLocationNfsRequest
 
DescribeLocationNfsResponse
 
DescribeLocationObjectStorageRequest
 
DescribeLocationObjectStorageResponse
 
DescribeLocationS3Request
 
DescribeLocationS3Response
 
DescribeLocationSmbRequest
 
DescribeLocationSmbResponse
 
DescribeTaskExecutionRequest
 
DescribeTaskExecutionResponse
 
DescribeTaskRequest
 
DescribeTaskResponse
 
The subnet and security groups that DataSync uses to connect to one of your Amazon EFS file system's mount targets.
 
 
Link between an endpoint property and the AwsEndpointAttribute it represents.
 
 
 
Specifies which files, folders, and objects to include or exclude when transferring files from source to destination.
 
 
Specifies the data transfer protocol that DataSync uses to access your Amazon FSx file system.
 
Specifies the Network File System (NFS) protocol configuration that DataSync uses to access your FSx for OpenZFS file system or FSx for ONTAP file system's storage virtual machine (SVM).
 
Specifies the Server Message Block (SMB) protocol configuration that DataSync uses to access your Amazon FSx for NetApp ONTAP file system's storage virtual machine (SVM).
 
Specifies the data transfer protocol that DataSync uses to access your Amazon FSx file system.
 
Specifies the Server Message Block (SMB) protocol configuration that DataSync uses to access your Amazon FSx for NetApp ONTAP file system's storage virtual machine (SVM).
 
 
 
 
The NameNode of the Hadoop Distributed File System (HDFS).
 
 
Identifiers for variables declared within the rule engine, e.g.
This exception is thrown when an error occurs in the DataSync service.
 
This exception is thrown when the client submits a malformed request.
 
Represents the output for the DataSyncClient.listAgentsPaginator(software.amazon.awssdk.services.datasync.model.ListAgentsRequest) operation which is a paginated operation.
Represents the output for the DataSyncAsyncClient.listAgentsPaginator(software.amazon.awssdk.services.datasync.model.ListAgentsRequest) operation which is a paginated operation.
ListAgentsRequest
 
ListAgentsResponse
 
Represents the output for the DataSyncClient.listLocationsPaginator(software.amazon.awssdk.services.datasync.model.ListLocationsRequest) operation which is a paginated operation.
ListLocationsRequest
 
ListLocationsResponse
 
ListTagsForResourceRequest
 
ListTagsForResourceResponse
 
ListTaskExecutions
 
ListTaskExecutionsResponse
 
Represents the output for the DataSyncClient.listTasksPaginator(software.amazon.awssdk.services.datasync.model.ListTasksRequest) operation which is a paginated operation.
Represents the output for the DataSyncAsyncClient.listTasksPaginator(software.amazon.awssdk.services.datasync.model.ListTasksRequest) operation which is a paginated operation.
ListTasksRequest
 
ListTasksRequest Marshaller
ListTasksResponse
 
Narrow down the list of resources returned by ListLocations.
 
 
Represents a single entry in a list of locations.
 
 
Specifies configuration information for a DataSync-managed secret, such as an authentication token or set of credentials that DataSync uses to access a specific transfer location.
 
 
Configures a manifest, which is a list of files or objects that you want DataSync to transfer.
 
 
 
Specifies how DataSync can access a location using the NFS protocol.
 
 
 
 
 
The DataSync agents that can connect to your Network File System (NFS) file server.
 
 
Indicates how your transfer task is configured.
 
 
 
 
 
 
 
 
 
 
The platform-related details about the DataSync agent, such as the version number.
 
 
 
 
 
Specifies how your DataSync agent connects to Amazon Web Services using a virtual private cloud (VPC) service endpoint.
 
The Quality of Protection (QOP) configuration specifies the Remote Procedure Call (RPC) and data transfer privacy settings configured on the Hadoop Distributed File System (HDFS) cluster.
 
 
 
Specifies where DataSync uploads your task report.
 
Specifies the Amazon S3 bucket where DataSync uploads your task report.
 
 
 
Specifies the level of detail for a particular aspect of your DataSync task report.
 
The level of detail included in each aspect of your DataSync task report.
 
Indicates whether DataSync created a complete task report for your transfer.
 
 
 
 
 
 
Represents a URL to be used internally for endpoint resolution.
Specifies the Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that DataSync uses to access your S3 bucket.
 
Specifies the S3 bucket where you're hosting the manifest that you want DataSync to use.
 
 
 
 
 
 
Specifies the version of the Server Message Block (SMB) protocol that DataSync uses to access an SMB file server.
 
 
 
Specifies the manifest that you want DataSync to use and where it's hosted.
 
StartTaskExecutionRequest
 
StartTaskExecutionResponse
 
A key-value pair representing a single tag that's been applied to an Amazon Web Services resource.
 
TagResourceRequest
 
 
 
The number of files or objects that DataSync fails to prepare, transfer, verify, and delete during your task execution.
 
The number of files or objects that DataSync finds at your locations.
 
The number of directories that DataSync fails to list, prepare, transfer, verify, and delete during your task execution.
 
The number of directories that DataSync finds at your locations.
 
Represents a single entry in a list of DataSync task executions that's returned with the ListTaskExecutions operation.
 
Provides detailed information about the result of your DataSync task execution.
 
 
You can use API filters to narrow down the list of resources returned by ListTasks.
 
 
Represents a single entry in a list of tasks.
 
 
 
Specifies how you want to configure a task report, which provides detailed information about for your DataSync transfer.
 
Configures your DataSync task to run on a schedule (at a minimum interval of 1 hour).
 
Provides information about your DataSync task schedule.
 
 
 
 
UntagResourceRequest
 
 
 
UpdateAgentRequest
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
UpdateTaskResponse
 
 
 
 
Base class for the types of values computable by the RuleEngine.
An array value.
A boolean value.
 
 
An integer value.
 
A record (map) value.
A string value.