Class CreateAgentRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<CreateAgentRequest.Builder,CreateAgentRequest>

@Generated("software.amazon.awssdk:codegen") public final class CreateAgentRequest extends DataSyncRequest implements ToCopyableBuilder<CreateAgentRequest.Builder,CreateAgentRequest>

CreateAgentRequest

  • Method Details

    • activationKey

      public final String activationKey()

      Specifies your DataSync agent's activation key. If you don't have an activation key, see Activating your agent.

      Returns:
      Specifies your DataSync agent's activation key. If you don't have an activation key, see Activating your agent.
    • agentName

      public final String agentName()

      Specifies a name for your agent. We recommend specifying a name that you can remember.

      Returns:
      Specifies a name for your agent. We recommend specifying a name that you can remember.
    • hasTags

      public final boolean hasTags()
      For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • tags

      public final List<TagListEntry> tags()

      Specifies labels that help you categorize, filter, and search for your Amazon Web Services resources. We recommend creating at least one tag for your agent.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasTags() method.

      Returns:
      Specifies labels that help you categorize, filter, and search for your Amazon Web Services resources. We recommend creating at least one tag for your agent.
    • vpcEndpointId

      public final String vpcEndpointId()

      Specifies the ID of the VPC service endpoint that you're using. For example, a VPC endpoint ID looks like vpce-01234d5aff67890e1.

      The VPC service endpoint you use must include the DataSync service name (for example, com.amazonaws.us-east-2.datasync).

      Returns:
      Specifies the ID of the VPC service endpoint that you're using. For example, a VPC endpoint ID looks like vpce-01234d5aff67890e1.

      The VPC service endpoint you use must include the DataSync service name (for example, com.amazonaws.us-east-2.datasync).

    • hasSubnetArns

      public final boolean hasSubnetArns()
      For responses, this returns true if the service returned a value for the SubnetArns property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • subnetArns

      public final List<String> subnetArns()

      Specifies the ARN of the subnet where your VPC service endpoint is located. You can only specify one ARN.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasSubnetArns() method.

      Returns:
      Specifies the ARN of the subnet where your VPC service endpoint is located. You can only specify one ARN.
    • hasSecurityGroupArns

      public final boolean hasSecurityGroupArns()
      For responses, this returns true if the service returned a value for the SecurityGroupArns property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • securityGroupArns

      public final List<String> securityGroupArns()

      Specifies the Amazon Resource Name (ARN) of the security group that allows traffic between your agent and VPC service endpoint. You can only specify one ARN.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasSecurityGroupArns() method.

      Returns:
      Specifies the Amazon Resource Name (ARN) of the security group that allows traffic between your agent and VPC service endpoint. You can only specify one ARN.
    • toBuilder

      public CreateAgentRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<CreateAgentRequest.Builder,CreateAgentRequest>
      Specified by:
      toBuilder in class DataSyncRequest
    • builder

      public static CreateAgentRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends CreateAgentRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo