Class CreateLocationObjectStorageRequest
- java.lang.Object
-
- software.amazon.awssdk.core.SdkRequest
-
- software.amazon.awssdk.awscore.AwsRequest
-
- software.amazon.awssdk.services.datasync.model.DataSyncRequest
-
- software.amazon.awssdk.services.datasync.model.CreateLocationObjectStorageRequest
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateLocationObjectStorageRequest.Builder,CreateLocationObjectStorageRequest>
@Generated("software.amazon.awssdk:codegen") public final class CreateLocationObjectStorageRequest extends DataSyncRequest implements ToCopyableBuilder<CreateLocationObjectStorageRequest.Builder,CreateLocationObjectStorageRequest>
CreateLocationObjectStorageRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceCreateLocationObjectStorageRequest.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description StringaccessKey()Specifies the access key (for example, a user name) if credentials are required to authenticate with the object storage server.List<String>agentArns()(Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your object storage system.StringbucketName()Specifies the name of the object storage bucket involved in the transfer.static CreateLocationObjectStorageRequest.Builderbuilder()CmkSecretConfigcmkSecretConfig()Specifies configuration information for a DataSync-managed secret, which includes theSecretKeythat DataSync uses to access a specific object storage location, with a customer-managed KMS key.CustomSecretConfigcustomSecretConfig()Specifies configuration information for a customer-managed Secrets Manager secret where the secret key for a specific object storage location is stored in plain text, in Secrets Manager.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)booleanhasAgentArns()For responses, this returns true if the service returned a value for the AgentArns property.inthashCode()booleanhasTags()For responses, this returns true if the service returned a value for the Tags property.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()StringsecretKey()Specifies the secret key (for example, a password) if credentials are required to authenticate with the object storage server.static Class<? extends CreateLocationObjectStorageRequest.Builder>serializableBuilderClass()SdkBytesserverCertificate()Specifies a certificate chain for DataSync to authenticate with your object storage system if the system uses a private or self-signed certificate authority (CA).StringserverHostname()Specifies the domain name or IP address (IPv4 or IPv6) of the object storage server that your DataSync agent connects to.IntegerserverPort()Specifies the port that your object storage server accepts inbound network traffic on (for example, port 443).ObjectStorageServerProtocolserverProtocol()Specifies the protocol that your object storage server uses to communicate.StringserverProtocolAsString()Specifies the protocol that your object storage server uses to communicate.Stringsubdirectory()Specifies the object prefix for your object storage server.List<TagListEntry>tags()Specifies the key-value pair that represents a tag that you want to add to the resource.CreateLocationObjectStorageRequest.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfiguration
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
serverHostname
public final String serverHostname()
Specifies the domain name or IP address (IPv4 or IPv6) of the object storage server that your DataSync agent connects to.
- Returns:
- Specifies the domain name or IP address (IPv4 or IPv6) of the object storage server that your DataSync agent connects to.
-
serverPort
public final Integer serverPort()
Specifies the port that your object storage server accepts inbound network traffic on (for example, port 443).
- Returns:
- Specifies the port that your object storage server accepts inbound network traffic on (for example, port 443).
-
serverProtocol
public final ObjectStorageServerProtocol serverProtocol()
Specifies the protocol that your object storage server uses to communicate. If not specified, the default value is
HTTPS.If the service returns an enum value that is not available in the current SDK version,
serverProtocolwill returnObjectStorageServerProtocol.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromserverProtocolAsString().- Returns:
- Specifies the protocol that your object storage server uses to communicate. If not specified, the default
value is
HTTPS. - See Also:
ObjectStorageServerProtocol
-
serverProtocolAsString
public final String serverProtocolAsString()
Specifies the protocol that your object storage server uses to communicate. If not specified, the default value is
HTTPS.If the service returns an enum value that is not available in the current SDK version,
serverProtocolwill returnObjectStorageServerProtocol.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromserverProtocolAsString().- Returns:
- Specifies the protocol that your object storage server uses to communicate. If not specified, the default
value is
HTTPS. - See Also:
ObjectStorageServerProtocol
-
subdirectory
public final String subdirectory()
Specifies the object prefix for your object storage server. If this is a source location, DataSync only copies objects with this prefix. If this is a destination location, DataSync writes all objects with this prefix.
- Returns:
- Specifies the object prefix for your object storage server. If this is a source location, DataSync only copies objects with this prefix. If this is a destination location, DataSync writes all objects with this prefix.
-
bucketName
public final String bucketName()
Specifies the name of the object storage bucket involved in the transfer.
- Returns:
- Specifies the name of the object storage bucket involved in the transfer.
-
accessKey
public final String accessKey()
Specifies the access key (for example, a user name) if credentials are required to authenticate with the object storage server.
- Returns:
- Specifies the access key (for example, a user name) if credentials are required to authenticate with the object storage server.
-
secretKey
public final String secretKey()
Specifies the secret key (for example, a password) if credentials are required to authenticate with the object storage server.
If you provide a secret using
SecretKey, but do not provide secret configuration details usingCmkSecretConfigorCustomSecretConfig, then DataSync stores the token using your Amazon Web Services account's Secrets Manager secret.- Returns:
- Specifies the secret key (for example, a password) if credentials are required to authenticate with the
object storage server.
If you provide a secret using
SecretKey, but do not provide secret configuration details usingCmkSecretConfigorCustomSecretConfig, then DataSync stores the token using your Amazon Web Services account's Secrets Manager secret.
-
hasAgentArns
public final boolean hasAgentArns()
For responses, this returns true if the service returned a value for the AgentArns property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
agentArns
public final List<String> agentArns()
(Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your object storage system. If you are setting up an agentless cross-cloud transfer, you do not need to specify a value for this parameter.
Make sure you configure this parameter correctly when you first create your storage location. You cannot add or remove agents from a storage location after you create it.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasAgentArns()method.- Returns:
- (Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your
object storage system. If you are setting up an agentless cross-cloud transfer, you do not need to
specify a value for this parameter.
Make sure you configure this parameter correctly when you first create your storage location. You cannot add or remove agents from a storage location after you create it.
-
hasTags
public final boolean hasTags()
For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
tags
public final List<TagListEntry> tags()
Specifies the key-value pair that represents a tag that you want to add to the resource. Tags can help you manage, filter, and search for your resources. We recommend creating a name tag for your location.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTags()method.- Returns:
- Specifies the key-value pair that represents a tag that you want to add to the resource. Tags can help you manage, filter, and search for your resources. We recommend creating a name tag for your location.
-
serverCertificate
public final SdkBytes serverCertificate()
Specifies a certificate chain for DataSync to authenticate with your object storage system if the system uses a private or self-signed certificate authority (CA). You must specify a single
.pemfile with a full certificate chain (for example,file:///home/user/.ssh/object_storage_certificates.pem).The certificate chain might include:
-
The object storage system's certificate
-
All intermediate certificates (if there are any)
-
The root certificate of the signing CA
You can concatenate your certificates into a
.pemfile (which can be up to 32768 bytes before base64 encoding). The following examplecatcommand creates anobject_storage_certificates.pemfile that includes three certificates:cat object_server_certificate.pem intermediate_certificate.pem ca_root_certificate.pem > object_storage_certificates.pemTo use this parameter, configure
ServerProtocoltoHTTPS.- Returns:
- Specifies a certificate chain for DataSync to authenticate with your object storage system if the system
uses a private or self-signed certificate authority (CA). You must specify a single
.pemfile with a full certificate chain (for example,file:///home/user/.ssh/object_storage_certificates.pem).The certificate chain might include:
-
The object storage system's certificate
-
All intermediate certificates (if there are any)
-
The root certificate of the signing CA
You can concatenate your certificates into a
.pemfile (which can be up to 32768 bytes before base64 encoding). The following examplecatcommand creates anobject_storage_certificates.pemfile that includes three certificates:cat object_server_certificate.pem intermediate_certificate.pem ca_root_certificate.pem > object_storage_certificates.pemTo use this parameter, configure
ServerProtocoltoHTTPS. -
-
-
cmkSecretConfig
public final CmkSecretConfig cmkSecretConfig()
Specifies configuration information for a DataSync-managed secret, which includes the
SecretKeythat DataSync uses to access a specific object storage location, with a customer-managed KMS key.When you include this parameter as part of a
CreateLocationObjectStoragerequest, you provide only the KMS key ARN. DataSync uses this KMS key together with the value you specify for theSecretKeyparameter to create a DataSync-managed secret to store the location access credentials.Make sure that DataSync has permission to access the KMS key that you specify.
You can use either
CmkSecretConfig(withSecretKey) orCustomSecretConfig(withoutSecretKey) to provide credentials for aCreateLocationObjectStoragerequest. Do not provide both parameters for the same request.- Returns:
- Specifies configuration information for a DataSync-managed secret, which includes the
SecretKeythat DataSync uses to access a specific object storage location, with a customer-managed KMS key.When you include this parameter as part of a
CreateLocationObjectStoragerequest, you provide only the KMS key ARN. DataSync uses this KMS key together with the value you specify for theSecretKeyparameter to create a DataSync-managed secret to store the location access credentials.Make sure that DataSync has permission to access the KMS key that you specify.
You can use either
CmkSecretConfig(withSecretKey) orCustomSecretConfig(withoutSecretKey) to provide credentials for aCreateLocationObjectStoragerequest. Do not provide both parameters for the same request.
-
customSecretConfig
public final CustomSecretConfig customSecretConfig()
Specifies configuration information for a customer-managed Secrets Manager secret where the secret key for a specific object storage location is stored in plain text, in Secrets Manager. This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret.
You can use either
CmkSecretConfig(withSecretKey) orCustomSecretConfig(withoutSecretKey) to provide credentials for aCreateLocationObjectStoragerequest. Do not provide both parameters for the same request.- Returns:
- Specifies configuration information for a customer-managed Secrets Manager secret where the secret key
for a specific object storage location is stored in plain text, in Secrets Manager. This configuration
includes the secret ARN, and the ARN for an IAM role that provides access to the secret.
You can use either
CmkSecretConfig(withSecretKey) orCustomSecretConfig(withoutSecretKey) to provide credentials for aCreateLocationObjectStoragerequest. Do not provide both parameters for the same request.
-
toBuilder
public CreateLocationObjectStorageRequest.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateLocationObjectStorageRequest.Builder,CreateLocationObjectStorageRequest>- Specified by:
toBuilderin classDataSyncRequest
-
builder
public static CreateLocationObjectStorageRequest.Builder builder()
-
serializableBuilderClass
public static Class<? extends CreateLocationObjectStorageRequest.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsRequest
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-