Interface CreateLocationObjectStorageRequest.Builder
-
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<CreateLocationObjectStorageRequest.Builder,CreateLocationObjectStorageRequest>,DataSyncRequest.Builder,SdkBuilder<CreateLocationObjectStorageRequest.Builder,CreateLocationObjectStorageRequest>,SdkPojo,SdkRequest.Builder
- Enclosing class:
- CreateLocationObjectStorageRequest
@Mutable @NotThreadSafe public static interface CreateLocationObjectStorageRequest.Builder extends DataSyncRequest.Builder, SdkPojo, CopyableBuilder<CreateLocationObjectStorageRequest.Builder,CreateLocationObjectStorageRequest>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description CreateLocationObjectStorageRequest.BuilderaccessKey(String accessKey)Specifies the access key (for example, a user name) if credentials are required to authenticate with the object storage server.CreateLocationObjectStorageRequest.BuilderagentArns(String... agentArns)(Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your object storage system.CreateLocationObjectStorageRequest.BuilderagentArns(Collection<String> agentArns)(Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your object storage system.CreateLocationObjectStorageRequest.BuilderbucketName(String bucketName)Specifies the name of the object storage bucket involved in the transfer.default CreateLocationObjectStorageRequest.BuildercmkSecretConfig(Consumer<CmkSecretConfig.Builder> cmkSecretConfig)Specifies configuration information for a DataSync-managed secret, which includes theSecretKeythat DataSync uses to access a specific object storage location, with a customer-managed KMS key.CreateLocationObjectStorageRequest.BuildercmkSecretConfig(CmkSecretConfig cmkSecretConfig)Specifies configuration information for a DataSync-managed secret, which includes theSecretKeythat DataSync uses to access a specific object storage location, with a customer-managed KMS key.default CreateLocationObjectStorageRequest.BuildercustomSecretConfig(Consumer<CustomSecretConfig.Builder> customSecretConfig)Specifies configuration information for a customer-managed Secrets Manager secret where the secret key for a specific object storage location is stored in plain text, in Secrets Manager.CreateLocationObjectStorageRequest.BuildercustomSecretConfig(CustomSecretConfig customSecretConfig)Specifies configuration information for a customer-managed Secrets Manager secret where the secret key for a specific object storage location is stored in plain text, in Secrets Manager.CreateLocationObjectStorageRequest.BuilderoverrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)CreateLocationObjectStorageRequest.BuilderoverrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)CreateLocationObjectStorageRequest.BuildersecretKey(String secretKey)Specifies the secret key (for example, a password) if credentials are required to authenticate with the object storage server.CreateLocationObjectStorageRequest.BuilderserverCertificate(SdkBytes serverCertificate)Specifies a certificate chain for DataSync to authenticate with your object storage system if the system uses a private or self-signed certificate authority (CA).CreateLocationObjectStorageRequest.BuilderserverHostname(String serverHostname)Specifies the domain name or IP address (IPv4 or IPv6) of the object storage server that your DataSync agent connects to.CreateLocationObjectStorageRequest.BuilderserverPort(Integer serverPort)Specifies the port that your object storage server accepts inbound network traffic on (for example, port 443).CreateLocationObjectStorageRequest.BuilderserverProtocol(String serverProtocol)Specifies the protocol that your object storage server uses to communicate.CreateLocationObjectStorageRequest.BuilderserverProtocol(ObjectStorageServerProtocol serverProtocol)Specifies the protocol that your object storage server uses to communicate.CreateLocationObjectStorageRequest.Buildersubdirectory(String subdirectory)Specifies the object prefix for your object storage server.CreateLocationObjectStorageRequest.Buildertags(Collection<TagListEntry> tags)Specifies the key-value pair that represents a tag that you want to add to the resource.CreateLocationObjectStorageRequest.Buildertags(Consumer<TagListEntry.Builder>... tags)Specifies the key-value pair that represents a tag that you want to add to the resource.CreateLocationObjectStorageRequest.Buildertags(TagListEntry... tags)Specifies the key-value pair that represents a tag that you want to add to the resource.-
Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfiguration
-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.services.datasync.model.DataSyncRequest.Builder
build
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
serverHostname
CreateLocationObjectStorageRequest.Builder serverHostname(String serverHostname)
Specifies the domain name or IP address (IPv4 or IPv6) of the object storage server that your DataSync agent connects to.
- Parameters:
serverHostname- Specifies the domain name or IP address (IPv4 or IPv6) of the object storage server that your DataSync agent connects to.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
serverPort
CreateLocationObjectStorageRequest.Builder serverPort(Integer serverPort)
Specifies the port that your object storage server accepts inbound network traffic on (for example, port 443).
- Parameters:
serverPort- Specifies the port that your object storage server accepts inbound network traffic on (for example, port 443).- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
serverProtocol
CreateLocationObjectStorageRequest.Builder serverProtocol(String serverProtocol)
Specifies the protocol that your object storage server uses to communicate. If not specified, the default value is
HTTPS.- Parameters:
serverProtocol- Specifies the protocol that your object storage server uses to communicate. If not specified, the default value isHTTPS.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
ObjectStorageServerProtocol,ObjectStorageServerProtocol
-
serverProtocol
CreateLocationObjectStorageRequest.Builder serverProtocol(ObjectStorageServerProtocol serverProtocol)
Specifies the protocol that your object storage server uses to communicate. If not specified, the default value is
HTTPS.- Parameters:
serverProtocol- Specifies the protocol that your object storage server uses to communicate. If not specified, the default value isHTTPS.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
ObjectStorageServerProtocol,ObjectStorageServerProtocol
-
subdirectory
CreateLocationObjectStorageRequest.Builder subdirectory(String subdirectory)
Specifies the object prefix for your object storage server. If this is a source location, DataSync only copies objects with this prefix. If this is a destination location, DataSync writes all objects with this prefix.
- Parameters:
subdirectory- Specifies the object prefix for your object storage server. If this is a source location, DataSync only copies objects with this prefix. If this is a destination location, DataSync writes all objects with this prefix.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
bucketName
CreateLocationObjectStorageRequest.Builder bucketName(String bucketName)
Specifies the name of the object storage bucket involved in the transfer.
- Parameters:
bucketName- Specifies the name of the object storage bucket involved in the transfer.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
accessKey
CreateLocationObjectStorageRequest.Builder accessKey(String accessKey)
Specifies the access key (for example, a user name) if credentials are required to authenticate with the object storage server.
- Parameters:
accessKey- Specifies the access key (for example, a user name) if credentials are required to authenticate with the object storage server.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
secretKey
CreateLocationObjectStorageRequest.Builder secretKey(String secretKey)
Specifies the secret key (for example, a password) if credentials are required to authenticate with the object storage server.
If you provide a secret using
SecretKey, but do not provide secret configuration details usingCmkSecretConfigorCustomSecretConfig, then DataSync stores the token using your Amazon Web Services account's Secrets Manager secret.- Parameters:
secretKey- Specifies the secret key (for example, a password) if credentials are required to authenticate with the object storage server.If you provide a secret using
SecretKey, but do not provide secret configuration details usingCmkSecretConfigorCustomSecretConfig, then DataSync stores the token using your Amazon Web Services account's Secrets Manager secret.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
agentArns
CreateLocationObjectStorageRequest.Builder agentArns(Collection<String> agentArns)
(Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your object storage system. If you are setting up an agentless cross-cloud transfer, you do not need to specify a value for this parameter.
Make sure you configure this parameter correctly when you first create your storage location. You cannot add or remove agents from a storage location after you create it.
- Parameters:
agentArns- (Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your object storage system. If you are setting up an agentless cross-cloud transfer, you do not need to specify a value for this parameter.Make sure you configure this parameter correctly when you first create your storage location. You cannot add or remove agents from a storage location after you create it.
- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
agentArns
CreateLocationObjectStorageRequest.Builder agentArns(String... agentArns)
(Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your object storage system. If you are setting up an agentless cross-cloud transfer, you do not need to specify a value for this parameter.
Make sure you configure this parameter correctly when you first create your storage location. You cannot add or remove agents from a storage location after you create it.
- Parameters:
agentArns- (Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your object storage system. If you are setting up an agentless cross-cloud transfer, you do not need to specify a value for this parameter.Make sure you configure this parameter correctly when you first create your storage location. You cannot add or remove agents from a storage location after you create it.
- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
tags
CreateLocationObjectStorageRequest.Builder tags(Collection<TagListEntry> tags)
Specifies the key-value pair that represents a tag that you want to add to the resource. Tags can help you manage, filter, and search for your resources. We recommend creating a name tag for your location.
- Parameters:
tags- Specifies the key-value pair that represents a tag that you want to add to the resource. Tags can help you manage, filter, and search for your resources. We recommend creating a name tag for your location.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
tags
CreateLocationObjectStorageRequest.Builder tags(TagListEntry... tags)
Specifies the key-value pair that represents a tag that you want to add to the resource. Tags can help you manage, filter, and search for your resources. We recommend creating a name tag for your location.
- Parameters:
tags- Specifies the key-value pair that represents a tag that you want to add to the resource. Tags can help you manage, filter, and search for your resources. We recommend creating a name tag for your location.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
tags
CreateLocationObjectStorageRequest.Builder tags(Consumer<TagListEntry.Builder>... tags)
Specifies the key-value pair that represents a tag that you want to add to the resource. Tags can help you manage, filter, and search for your resources. We recommend creating a name tag for your location.
This is a convenience method that creates an instance of theTagListEntry.Builderavoiding the need to create one manually viaTagListEntry.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed to#tags(List.) - Parameters:
tags- a consumer that will call methods onTagListEntry.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
#tags(java.util.Collection)
-
serverCertificate
CreateLocationObjectStorageRequest.Builder serverCertificate(SdkBytes serverCertificate)
Specifies a certificate chain for DataSync to authenticate with your object storage system if the system uses a private or self-signed certificate authority (CA). You must specify a single
.pemfile with a full certificate chain (for example,file:///home/user/.ssh/object_storage_certificates.pem).The certificate chain might include:
-
The object storage system's certificate
-
All intermediate certificates (if there are any)
-
The root certificate of the signing CA
You can concatenate your certificates into a
.pemfile (which can be up to 32768 bytes before base64 encoding). The following examplecatcommand creates anobject_storage_certificates.pemfile that includes three certificates:cat object_server_certificate.pem intermediate_certificate.pem ca_root_certificate.pem > object_storage_certificates.pemTo use this parameter, configure
ServerProtocoltoHTTPS.- Parameters:
serverCertificate- Specifies a certificate chain for DataSync to authenticate with your object storage system if the system uses a private or self-signed certificate authority (CA). You must specify a single.pemfile with a full certificate chain (for example,file:///home/user/.ssh/object_storage_certificates.pem).The certificate chain might include:
-
The object storage system's certificate
-
All intermediate certificates (if there are any)
-
The root certificate of the signing CA
You can concatenate your certificates into a
.pemfile (which can be up to 32768 bytes before base64 encoding). The following examplecatcommand creates anobject_storage_certificates.pemfile that includes three certificates:cat object_server_certificate.pem intermediate_certificate.pem ca_root_certificate.pem > object_storage_certificates.pemTo use this parameter, configure
ServerProtocoltoHTTPS.-
- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-
cmkSecretConfig
CreateLocationObjectStorageRequest.Builder cmkSecretConfig(CmkSecretConfig cmkSecretConfig)
Specifies configuration information for a DataSync-managed secret, which includes the
SecretKeythat DataSync uses to access a specific object storage location, with a customer-managed KMS key.When you include this parameter as part of a
CreateLocationObjectStoragerequest, you provide only the KMS key ARN. DataSync uses this KMS key together with the value you specify for theSecretKeyparameter to create a DataSync-managed secret to store the location access credentials.Make sure that DataSync has permission to access the KMS key that you specify.
You can use either
CmkSecretConfig(withSecretKey) orCustomSecretConfig(withoutSecretKey) to provide credentials for aCreateLocationObjectStoragerequest. Do not provide both parameters for the same request.- Parameters:
cmkSecretConfig- Specifies configuration information for a DataSync-managed secret, which includes theSecretKeythat DataSync uses to access a specific object storage location, with a customer-managed KMS key.When you include this parameter as part of a
CreateLocationObjectStoragerequest, you provide only the KMS key ARN. DataSync uses this KMS key together with the value you specify for theSecretKeyparameter to create a DataSync-managed secret to store the location access credentials.Make sure that DataSync has permission to access the KMS key that you specify.
You can use either
CmkSecretConfig(withSecretKey) orCustomSecretConfig(withoutSecretKey) to provide credentials for aCreateLocationObjectStoragerequest. Do not provide both parameters for the same request.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
cmkSecretConfig
default CreateLocationObjectStorageRequest.Builder cmkSecretConfig(Consumer<CmkSecretConfig.Builder> cmkSecretConfig)
Specifies configuration information for a DataSync-managed secret, which includes the
SecretKeythat DataSync uses to access a specific object storage location, with a customer-managed KMS key.When you include this parameter as part of a
CreateLocationObjectStoragerequest, you provide only the KMS key ARN. DataSync uses this KMS key together with the value you specify for theSecretKeyparameter to create a DataSync-managed secret to store the location access credentials.Make sure that DataSync has permission to access the KMS key that you specify.
This is a convenience method that creates an instance of theYou can use either
CmkSecretConfig(withSecretKey) orCustomSecretConfig(withoutSecretKey) to provide credentials for aCreateLocationObjectStoragerequest. Do not provide both parameters for the same request.CmkSecretConfig.Builderavoiding the need to create one manually viaCmkSecretConfig.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tocmkSecretConfig(CmkSecretConfig).- Parameters:
cmkSecretConfig- a consumer that will call methods onCmkSecretConfig.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
cmkSecretConfig(CmkSecretConfig)
-
customSecretConfig
CreateLocationObjectStorageRequest.Builder customSecretConfig(CustomSecretConfig customSecretConfig)
Specifies configuration information for a customer-managed Secrets Manager secret where the secret key for a specific object storage location is stored in plain text, in Secrets Manager. This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret.
You can use either
CmkSecretConfig(withSecretKey) orCustomSecretConfig(withoutSecretKey) to provide credentials for aCreateLocationObjectStoragerequest. Do not provide both parameters for the same request.- Parameters:
customSecretConfig- Specifies configuration information for a customer-managed Secrets Manager secret where the secret key for a specific object storage location is stored in plain text, in Secrets Manager. This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret.You can use either
CmkSecretConfig(withSecretKey) orCustomSecretConfig(withoutSecretKey) to provide credentials for aCreateLocationObjectStoragerequest. Do not provide both parameters for the same request.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
customSecretConfig
default CreateLocationObjectStorageRequest.Builder customSecretConfig(Consumer<CustomSecretConfig.Builder> customSecretConfig)
Specifies configuration information for a customer-managed Secrets Manager secret where the secret key for a specific object storage location is stored in plain text, in Secrets Manager. This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret.
This is a convenience method that creates an instance of theYou can use either
CmkSecretConfig(withSecretKey) orCustomSecretConfig(withoutSecretKey) to provide credentials for aCreateLocationObjectStoragerequest. Do not provide both parameters for the same request.CustomSecretConfig.Builderavoiding the need to create one manually viaCustomSecretConfig.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed tocustomSecretConfig(CustomSecretConfig).- Parameters:
customSecretConfig- a consumer that will call methods onCustomSecretConfig.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
customSecretConfig(CustomSecretConfig)
-
overrideConfiguration
CreateLocationObjectStorageRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
CreateLocationObjectStorageRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
-