Class DescribeTaskExecutionResponse
- java.lang.Object
-
- software.amazon.awssdk.core.SdkResponse
-
- software.amazon.awssdk.awscore.AwsResponse
-
- software.amazon.awssdk.services.datasync.model.DataSyncResponse
-
- software.amazon.awssdk.services.datasync.model.DescribeTaskExecutionResponse
-
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribeTaskExecutionResponse.Builder,DescribeTaskExecutionResponse>
@Generated("software.amazon.awssdk:codegen") public final class DescribeTaskExecutionResponse extends DataSyncResponse implements ToCopyableBuilder<DescribeTaskExecutionResponse.Builder,DescribeTaskExecutionResponse>
DescribeTaskExecutionResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static interfaceDescribeTaskExecutionResponse.Builder
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static DescribeTaskExecutionResponse.Builderbuilder()LongbytesCompressed()The number of physical bytes that DataSync transfers over the network after compression (if compression is possible).LongbytesTransferred()The number of bytes that DataSync sends to the network before compression (if compression is possible).LongbytesWritten()The number of logical bytes that DataSync actually writes to the destination location.InstantendTime()The time that the transfer task ends.booleanequals(Object obj)booleanequalsBySdkFields(Object obj)LongestimatedBytesToTransfer()The number of logical bytes that DataSync expects to write to the destination location.LongestimatedFilesToDelete()The number of files, objects, and directories that DataSync expects to delete in your destination location.LongestimatedFilesToTransfer()The number of files, objects, and directories that DataSync expects to transfer over the network.LongestimatedFoldersToDelete()The number of directories that DataSync expects to delete in your destination location.LongestimatedFoldersToTransfer()The number of directories that DataSync expects to transfer over the network.List<FilterRule>excludes()A list of filter rules that exclude specific data during your transfer.LongfilesDeleted()The number of files, objects, and directories that DataSync actually deletes in your destination location.TaskExecutionFilesFailedDetailfilesFailed()The number of files or objects that DataSync fails to prepare, transfer, verify, and delete during your task execution.TaskExecutionFilesListedDetailfilesListed()The number of files or objects that DataSync finds at your locations.LongfilesPrepared()The number of files or objects that DataSync will attempt to transfer after comparing your source and destination locations.LongfilesSkipped()The number of files, objects, and directories that DataSync skips during your transfer.LongfilesTransferred()The number of files, objects, and directories that DataSync actually transfers over the network.LongfilesVerified()The number of files, objects, and directories that DataSync verifies during your transfer.LongfoldersDeleted()The number of directories that DataSync actually deletes in your destination location.TaskExecutionFoldersFailedDetailfoldersFailed()The number of directories that DataSync fails to list, prepare, transfer, verify, and delete during your task execution.TaskExecutionFoldersListedDetailfoldersListed()The number of directories that DataSync finds at your locations.LongfoldersPrepared()The number of directories that DataSync will attempt to transfer after comparing your source and destination locations.LongfoldersSkipped()The number of directories that DataSync skips during your transfer.LongfoldersTransferred()The number of directories that DataSync actually transfers over the network.LongfoldersVerified()The number of directories that DataSync verifies during your transfer.<T> Optional<T>getValueForField(String fieldName, Class<T> clazz)booleanhasExcludes()For responses, this returns true if the service returned a value for the Excludes property.inthashCode()booleanhasIncludes()For responses, this returns true if the service returned a value for the Includes property.List<FilterRule>includes()A list of filter rules that include specific data during your transfer.InstantlaunchTime()The time that the task execution actually begins.ManifestConfigmanifestConfig()The configuration of the manifest that lists the files or objects to transfer.Optionsoptions()Returns the value of the Options property for this object.ReportResultreportResult()Indicates whether DataSync generated a complete task report for your transfer.TaskExecutionResultDetailresult()The result of the task execution.Map<String,SdkField<?>>sdkFieldNameToField()List<SdkField<?>>sdkFields()static Class<? extends DescribeTaskExecutionResponse.Builder>serializableBuilderClass()InstantstartTime()The time that DataSync sends the request to start the task execution.TaskExecutionStatusstatus()The status of the task execution.StringstatusAsString()The status of the task execution.StringtaskExecutionArn()The ARN of the task execution that you wanted information about.TaskModetaskMode()The task mode that you're using.StringtaskModeAsString()The task mode that you're using.TaskReportConfigtaskReportConfig()The configuration of your task report, which provides detailed information about for your DataSync transfer.DescribeTaskExecutionResponse.BuildertoBuilder()StringtoString()Returns a string representation of this object.-
Methods inherited from class software.amazon.awssdk.services.datasync.model.DataSyncResponse
responseMetadata
-
Methods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponse
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
-
-
-
Method Detail
-
taskExecutionArn
public final String taskExecutionArn()
The ARN of the task execution that you wanted information about.
TaskExecutionArnis hierarchical and includesTaskArnfor the task that was executed.For example, a
TaskExecutionvalue with the ARNarn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019bexecuted the task with the ARNarn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2.- Returns:
- The ARN of the task execution that you wanted information about.
TaskExecutionArnis hierarchical and includesTaskArnfor the task that was executed.For example, a
TaskExecutionvalue with the ARNarn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2/execution/exec-08ef1e88ec491019bexecuted the task with the ARNarn:aws:datasync:us-east-1:111222333444:task/task-0208075f79cedf4a2.
-
status
public final TaskExecutionStatus status()
The status of the task execution.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnTaskExecutionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the task execution.
- See Also:
TaskExecutionStatus
-
statusAsString
public final String statusAsString()
The status of the task execution.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnTaskExecutionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the task execution.
- See Also:
TaskExecutionStatus
-
options
public final Options options()
Returns the value of the Options property for this object.- Returns:
- The value of the Options property for this object.
-
hasExcludes
public final boolean hasExcludes()
For responses, this returns true if the service returned a value for the Excludes property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
excludes
public final List<FilterRule> excludes()
A list of filter rules that exclude specific data during your transfer. For more information and examples, see Filtering data transferred by DataSync.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasExcludes()method.- Returns:
- A list of filter rules that exclude specific data during your transfer. For more information and examples, see Filtering data transferred by DataSync.
-
hasIncludes
public final boolean hasIncludes()
For responses, this returns true if the service returned a value for the Includes property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
-
includes
public final List<FilterRule> includes()
A list of filter rules that include specific data during your transfer. For more information and examples, see Filtering data transferred by DataSync.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasIncludes()method.- Returns:
- A list of filter rules that include specific data during your transfer. For more information and examples, see Filtering data transferred by DataSync.
-
manifestConfig
public final ManifestConfig manifestConfig()
The configuration of the manifest that lists the files or objects to transfer. For more information, see Specifying what DataSync transfers by using a manifest.
- Returns:
- The configuration of the manifest that lists the files or objects to transfer. For more information, see Specifying what DataSync transfers by using a manifest.
-
startTime
public final Instant startTime()
The time that DataSync sends the request to start the task execution. For non-queued tasks,
LaunchTimeandStartTimeare typically the same. For queued tasks,LaunchTimeis typically later thanStartTimebecause previously queued tasks must finish running before newer tasks can begin.- Returns:
- The time that DataSync sends the request to start the task execution. For non-queued tasks,
LaunchTimeandStartTimeare typically the same. For queued tasks,LaunchTimeis typically later thanStartTimebecause previously queued tasks must finish running before newer tasks can begin.
-
estimatedFilesToTransfer
public final Long estimatedFilesToTransfer()
The number of files, objects, and directories that DataSync expects to transfer over the network. This value is calculated while DataSync prepares the transfer.
How this gets calculated depends primarily on your task’s transfer mode configuration:
-
If
TranserModeis set toCHANGED- The calculation is based on comparing the content of the source and destination locations and determining the difference that needs to be transferred. The difference can include:-
Anything that's added or modified at the source location.
-
Anything that's in both locations and modified at the destination after an initial transfer (unless OverwriteMode is set to
NEVER). -
(Basic task mode only) The number of items that DataSync expects to delete (if PreserveDeletedFiles is set to
REMOVE).
-
-
If
TranserModeis set toALL- The calculation is based only on the items that DataSync finds at the source location.
For Enhanced mode tasks, this counter only includes files or objects. Directories are counted in EstimatedFoldersToTransfer.
- Returns:
- The number of files, objects, and directories that DataSync expects to transfer over the network. This
value is calculated while DataSync prepares the transfer.
How this gets calculated depends primarily on your task’s transfer mode configuration:
-
If
TranserModeis set toCHANGED- The calculation is based on comparing the content of the source and destination locations and determining the difference that needs to be transferred. The difference can include:-
Anything that's added or modified at the source location.
-
Anything that's in both locations and modified at the destination after an initial transfer (unless OverwriteMode is set to
NEVER). -
(Basic task mode only) The number of items that DataSync expects to delete (if PreserveDeletedFiles is set to
REMOVE).
-
-
If
TranserModeis set toALL- The calculation is based only on the items that DataSync finds at the source location.
For Enhanced mode tasks, this counter only includes files or objects. Directories are counted in EstimatedFoldersToTransfer.
-
-
-
estimatedBytesToTransfer
public final Long estimatedBytesToTransfer()
The number of logical bytes that DataSync expects to write to the destination location.
- Returns:
- The number of logical bytes that DataSync expects to write to the destination location.
-
filesTransferred
public final Long filesTransferred()
The number of files, objects, and directories that DataSync actually transfers over the network. This value is updated periodically during your task execution when something is read from the source and sent over the network.
If DataSync fails to transfer something, this value can be less than
EstimatedFilesToTransfer. In some cases, this value can also be greater thanEstimatedFilesToTransfer. This element is implementation-specific for some location types, so don't use it as an exact indication of what's transferring or to monitor your task execution.For Enhanced mode tasks, this counter only includes files or objects. Directories are counted in FoldersTransferred.
- Returns:
- The number of files, objects, and directories that DataSync actually transfers over the network. This
value is updated periodically during your task execution when something is read from the source and sent
over the network.
If DataSync fails to transfer something, this value can be less than
EstimatedFilesToTransfer. In some cases, this value can also be greater thanEstimatedFilesToTransfer. This element is implementation-specific for some location types, so don't use it as an exact indication of what's transferring or to monitor your task execution.For Enhanced mode tasks, this counter only includes files or objects. Directories are counted in FoldersTransferred.
-
bytesWritten
public final Long bytesWritten()
The number of logical bytes that DataSync actually writes to the destination location.
- Returns:
- The number of logical bytes that DataSync actually writes to the destination location.
-
bytesTransferred
public final Long bytesTransferred()
The number of bytes that DataSync sends to the network before compression (if compression is possible). For the number of bytes transferred over the network, see BytesCompressed.
- Returns:
- The number of bytes that DataSync sends to the network before compression (if compression is possible). For the number of bytes transferred over the network, see BytesCompressed.
-
bytesCompressed
public final Long bytesCompressed()
The number of physical bytes that DataSync transfers over the network after compression (if compression is possible). This number is typically less than BytesTransferred unless the data isn't compressible.
- Returns:
- The number of physical bytes that DataSync transfers over the network after compression (if compression is possible). This number is typically less than BytesTransferred unless the data isn't compressible.
-
result
public final TaskExecutionResultDetail result()
The result of the task execution.
- Returns:
- The result of the task execution.
-
taskReportConfig
public final TaskReportConfig taskReportConfig()
The configuration of your task report, which provides detailed information about for your DataSync transfer. For more information, see Creating a task report.
- Returns:
- The configuration of your task report, which provides detailed information about for your DataSync transfer. For more information, see Creating a task report.
-
filesDeleted
public final Long filesDeleted()
The number of files, objects, and directories that DataSync actually deletes in your destination location. If you don't configure your task to delete data in the destination that isn't in the source, the value is always
0.For Enhanced mode tasks, this counter only includes files or objects. Directories are counted in FoldersDeleted.
- Returns:
- The number of files, objects, and directories that DataSync actually deletes in your destination
location. If you don't configure your task to delete data in the
destination that isn't in the source, the value is always
0.For Enhanced mode tasks, this counter only includes files or objects. Directories are counted in FoldersDeleted.
-
filesSkipped
public final Long filesSkipped()
The number of files, objects, and directories that DataSync skips during your transfer.
For Enhanced mode tasks, this counter only includes files or objects. Directories are counted in FoldersSkipped.
- Returns:
- The number of files, objects, and directories that DataSync skips during your transfer.
For Enhanced mode tasks, this counter only includes files or objects. Directories are counted in FoldersSkipped.
-
filesVerified
public final Long filesVerified()
The number of files, objects, and directories that DataSync verifies during your transfer.
When you configure your task to verify only the data that's transferred, DataSync doesn't verify directories in some situations or files that fail to transfer.
For Enhanced mode tasks, this counter only includes files or objects. Directories are counted in FoldersVerified.
- Returns:
- The number of files, objects, and directories that DataSync verifies during your transfer.
When you configure your task to verify only the data that's transferred, DataSync doesn't verify directories in some situations or files that fail to transfer.
For Enhanced mode tasks, this counter only includes files or objects. Directories are counted in FoldersVerified.
-
reportResult
public final ReportResult reportResult()
Indicates whether DataSync generated a complete task report for your transfer.
- Returns:
- Indicates whether DataSync generated a complete task report for your transfer.
-
estimatedFilesToDelete
public final Long estimatedFilesToDelete()
The number of files, objects, and directories that DataSync expects to delete in your destination location. If you don't configure your task to delete data in the destination that isn't in the source, the value is always
0.For Enhanced mode tasks, this counter only includes files or objects. Directories are counted in EstimatedFoldersToDelete.
- Returns:
- The number of files, objects, and directories that DataSync expects to delete in your destination
location. If you don't configure your task to delete data in the
destination that isn't in the source, the value is always
0.For Enhanced mode tasks, this counter only includes files or objects. Directories are counted in EstimatedFoldersToDelete.
-
taskMode
public final TaskMode taskMode()
The task mode that you're using. For more information, see Choosing a task mode for your data transfer.
If the service returns an enum value that is not available in the current SDK version,
taskModewill returnTaskMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtaskModeAsString().- Returns:
- The task mode that you're using. For more information, see Choosing a task mode for your data transfer.
- See Also:
TaskMode
-
taskModeAsString
public final String taskModeAsString()
The task mode that you're using. For more information, see Choosing a task mode for your data transfer.
If the service returns an enum value that is not available in the current SDK version,
taskModewill returnTaskMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtaskModeAsString().- Returns:
- The task mode that you're using. For more information, see Choosing a task mode for your data transfer.
- See Also:
TaskMode
-
filesPrepared
public final Long filesPrepared()
The number of files or objects that DataSync will attempt to transfer after comparing your source and destination locations.
Applies only to Enhanced mode tasks.
This counter isn't applicable if you configure your task to transfer all data. In that scenario, DataSync copies everything from the source to the destination without comparing differences between the locations.
- Returns:
- The number of files or objects that DataSync will attempt to transfer after comparing your source and
destination locations.
Applies only to Enhanced mode tasks.
This counter isn't applicable if you configure your task to transfer all data. In that scenario, DataSync copies everything from the source to the destination without comparing differences between the locations.
-
filesListed
public final TaskExecutionFilesListedDetail filesListed()
The number of files or objects that DataSync finds at your locations.
Applies only to Enhanced mode tasks.
- Returns:
- The number of files or objects that DataSync finds at your locations.
Applies only to Enhanced mode tasks.
-
filesFailed
public final TaskExecutionFilesFailedDetail filesFailed()
The number of files or objects that DataSync fails to prepare, transfer, verify, and delete during your task execution.
Applies only to Enhanced mode tasks.
- Returns:
- The number of files or objects that DataSync fails to prepare, transfer, verify, and delete during your
task execution.
Applies only to Enhanced mode tasks.
-
estimatedFoldersToDelete
public final Long estimatedFoldersToDelete()
The number of directories that DataSync expects to delete in your destination location. If you don't configure your task to delete data in the destination that isn't in the source, the value is always
0.Applies only to Enhanced mode tasks.
- Returns:
- The number of directories that DataSync expects to delete in your destination location. If you don't
configure your task to delete data in the
destination that isn't in the source, the value is always
0.Applies only to Enhanced mode tasks.
-
estimatedFoldersToTransfer
public final Long estimatedFoldersToTransfer()
The number of directories that DataSync expects to transfer over the network. This value is calculated as DataSync prepares directories to transfer.
How this gets calculated depends primarily on your task’s transfer mode configuration:
-
If
TranserModeis set toCHANGED- The calculation is based on comparing the content of the source and destination locations and determining the difference that needs to be transferred. The difference can include:-
Anything that's added or modified at the source location.
-
Anything that's in both locations and modified at the destination after an initial transfer (unless OverwriteMode is set to
NEVER).
-
-
If
TranserModeis set toALL- The calculation is based only on the items that DataSync finds at the source location.
Applies only to Enhanced mode tasks.
- Returns:
- The number of directories that DataSync expects to transfer over the network. This value is calculated as
DataSync prepares directories to transfer.
How this gets calculated depends primarily on your task’s transfer mode configuration:
-
If
TranserModeis set toCHANGED- The calculation is based on comparing the content of the source and destination locations and determining the difference that needs to be transferred. The difference can include:-
Anything that's added or modified at the source location.
-
Anything that's in both locations and modified at the destination after an initial transfer (unless OverwriteMode is set to
NEVER).
-
-
If
TranserModeis set toALL- The calculation is based only on the items that DataSync finds at the source location.
Applies only to Enhanced mode tasks.
-
-
-
foldersSkipped
public final Long foldersSkipped()
The number of directories that DataSync skips during your transfer.
Applies only to Enhanced mode tasks.
- Returns:
- The number of directories that DataSync skips during your transfer.
Applies only to Enhanced mode tasks.
-
foldersPrepared
public final Long foldersPrepared()
The number of directories that DataSync will attempt to transfer after comparing your source and destination locations.
Applies only to Enhanced mode tasks.
This counter isn't applicable if you configure your task to transfer all data. In that scenario, DataSync copies everything from the source to the destination without comparing differences between the locations.
- Returns:
- The number of directories that DataSync will attempt to transfer after comparing your source and
destination locations.
Applies only to Enhanced mode tasks.
This counter isn't applicable if you configure your task to transfer all data. In that scenario, DataSync copies everything from the source to the destination without comparing differences between the locations.
-
foldersTransferred
public final Long foldersTransferred()
The number of directories that DataSync actually transfers over the network. This value is updated periodically during your task execution when something is read from the source and sent over the network.
If DataSync fails to transfer something, this value can be less than
EstimatedFoldersToTransfer. In some cases, this value can also be greater thanEstimatedFoldersToTransfer.Applies only to Enhanced mode tasks.
- Returns:
- The number of directories that DataSync actually transfers over the network. This value is updated
periodically during your task execution when something is read from the source and sent over the
network.
If DataSync fails to transfer something, this value can be less than
EstimatedFoldersToTransfer. In some cases, this value can also be greater thanEstimatedFoldersToTransfer.Applies only to Enhanced mode tasks.
-
foldersVerified
public final Long foldersVerified()
The number of directories that DataSync verifies during your transfer.
Applies only to Enhanced mode tasks.
- Returns:
- The number of directories that DataSync verifies during your transfer.
Applies only to Enhanced mode tasks.
-
foldersDeleted
public final Long foldersDeleted()
The number of directories that DataSync actually deletes in your destination location. If you don't configure your task to delete data in the destination that isn't in the source, the value is always
0.Applies only to Enhanced mode tasks.
- Returns:
- The number of directories that DataSync actually deletes in your destination location. If you don't
configure your task to delete data in the
destination that isn't in the source, the value is always
0.Applies only to Enhanced mode tasks.
-
foldersListed
public final TaskExecutionFoldersListedDetail foldersListed()
The number of directories that DataSync finds at your locations.
Applies only to Enhanced mode tasks.
- Returns:
- The number of directories that DataSync finds at your locations.
Applies only to Enhanced mode tasks.
-
foldersFailed
public final TaskExecutionFoldersFailedDetail foldersFailed()
The number of directories that DataSync fails to list, prepare, transfer, verify, and delete during your task execution.
Applies only to Enhanced mode tasks.
- Returns:
- The number of directories that DataSync fails to list, prepare, transfer, verify, and delete during your
task execution.
Applies only to Enhanced mode tasks.
-
launchTime
public final Instant launchTime()
The time that the task execution actually begins. For non-queued tasks,
LaunchTimeandStartTimeare typically the same. For queued tasks,LaunchTimeis typically later thanStartTimebecause previously queued tasks must finish running before newer tasks can begin.- Returns:
- The time that the task execution actually begins. For non-queued tasks,
LaunchTimeandStartTimeare typically the same. For queued tasks,LaunchTimeis typically later thanStartTimebecause previously queued tasks must finish running before newer tasks can begin.
-
endTime
public final Instant endTime()
The time that the transfer task ends.
- Returns:
- The time that the transfer task ends.
-
toBuilder
public DescribeTaskExecutionResponse.Builder toBuilder()
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribeTaskExecutionResponse.Builder,DescribeTaskExecutionResponse>- Specified by:
toBuilderin classAwsResponse
-
builder
public static DescribeTaskExecutionResponse.Builder builder()
-
serializableBuilderClass
public static Class<? extends DescribeTaskExecutionResponse.Builder> serializableBuilderClass()
-
hashCode
public final int hashCode()
- Overrides:
hashCodein classAwsResponse
-
equals
public final boolean equals(Object obj)
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
public final boolean equalsBySdkFields(Object obj)
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
public final String toString()
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
-
getValueForField
public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFieldNameToField
public final Map<String,SdkField<?>> sdkFieldNameToField()
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-
-