CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.accessKey(String accessKey) |
Specifies the access key (for example, a user name) if credentials are required to authenticate with the
object storage server.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.agentArns(String... agentArns) |
(Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your
object storage system.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.agentArns(Collection<String> agentArns) |
(Optional) Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your
object storage system.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.bucketName(String bucketName) |
Specifies the name of the object storage bucket involved in the transfer.
|
static CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.builder() |
|
default CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.cmkSecretConfig(Consumer<CmkSecretConfig.Builder> cmkSecretConfig) |
Specifies configuration information for a DataSync-managed secret, which includes the SecretKey
that DataSync uses to access a specific object storage location, with a customer-managed KMS key.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.cmkSecretConfig(CmkSecretConfig cmkSecretConfig) |
Specifies configuration information for a DataSync-managed secret, which includes the SecretKey
that DataSync uses to access a specific object storage location, with a customer-managed KMS key.
|
default CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.customSecretConfig(Consumer<CustomSecretConfig.Builder> customSecretConfig) |
Specifies configuration information for a customer-managed Secrets Manager secret where the secret key for a
specific object storage location is stored in plain text, in Secrets Manager.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.customSecretConfig(CustomSecretConfig customSecretConfig) |
Specifies configuration information for a customer-managed Secrets Manager secret where the secret key for a
specific object storage location is stored in plain text, in Secrets Manager.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) |
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) |
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.secretKey(String secretKey) |
Specifies the secret key (for example, a password) if credentials are required to authenticate with the
object storage server.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.serverCertificate(SdkBytes serverCertificate) |
Specifies a certificate chain for DataSync to authenticate with your object storage system if the system uses
a private or self-signed certificate authority (CA).
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.serverHostname(String serverHostname) |
Specifies the domain name or IP address (IPv4 or IPv6) of the object storage server that your DataSync agent
connects to.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.serverPort(Integer serverPort) |
Specifies the port that your object storage server accepts inbound network traffic on (for example, port
443).
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.serverProtocol(String serverProtocol) |
Specifies the protocol that your object storage server uses to communicate.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.serverProtocol(ObjectStorageServerProtocol serverProtocol) |
Specifies the protocol that your object storage server uses to communicate.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.subdirectory(String subdirectory) |
Specifies the object prefix for your object storage server.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.tags(Collection<TagListEntry> tags) |
Specifies the key-value pair that represents a tag that you want to add to the resource.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.tags(Consumer<TagListEntry.Builder>... tags) |
Specifies the key-value pair that represents a tag that you want to add to the resource.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.Builder.tags(TagListEntry... tags) |
Specifies the key-value pair that represents a tag that you want to add to the resource.
|
CreateLocationObjectStorageRequest.Builder |
CreateLocationObjectStorageRequest.toBuilder() |
|