Class CreateAgentRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateAgentRequest.Builder,CreateAgentRequest>
CreateAgentRequest
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringSpecifies your DataSync agent's activation key.final StringSpecifies a name for your agent.static CreateAgentRequest.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the SecurityGroupArns property.final booleanFor responses, this returns true if the service returned a value for the SubnetArns property.final booleanhasTags()For responses, this returns true if the service returned a value for the Tags property.Specifies the Amazon Resource Name (ARN) of the security group that allows traffic between your agent and VPC service endpoint.static Class<? extends CreateAgentRequest.Builder>Specifies the ARN of the subnet where your VPC service endpoint is located.final List<TagListEntry>tags()Specifies labels that help you categorize, filter, and search for your Amazon Web Services resources.final StringtoString()Returns a string representation of this object.final StringSpecifies the ID of the VPC service endpoint that you're using.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
activationKey
Specifies your DataSync agent's activation key. If you don't have an activation key, see Activating your agent.
- Returns:
- Specifies your DataSync agent's activation key. If you don't have an activation key, see Activating your agent.
-
agentName
Specifies a name for your agent. We recommend specifying a name that you can remember.
- Returns:
- Specifies a name for your agent. We recommend specifying a name that you can remember.
-
hasTags
public final boolean hasTags()For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
tags
Specifies labels that help you categorize, filter, and search for your Amazon Web Services resources. We recommend creating at least one tag for your agent.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTags()method.- Returns:
- Specifies labels that help you categorize, filter, and search for your Amazon Web Services resources. We recommend creating at least one tag for your agent.
-
vpcEndpointId
Specifies the ID of the VPC service endpoint that you're using. For example, a VPC endpoint ID looks like
vpce-01234d5aff67890e1.The VPC service endpoint you use must include the DataSync service name (for example,
com.amazonaws.us-east-2.datasync).- Returns:
- Specifies the ID of the VPC service endpoint that you're using. For example, a VPC endpoint ID looks like
vpce-01234d5aff67890e1.The VPC service endpoint you use must include the DataSync service name (for example,
com.amazonaws.us-east-2.datasync).
-
hasSubnetArns
public final boolean hasSubnetArns()For responses, this returns true if the service returned a value for the SubnetArns property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
subnetArns
Specifies the ARN of the subnet where your VPC service endpoint is located. You can only specify one ARN.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasSubnetArns()method.- Returns:
- Specifies the ARN of the subnet where your VPC service endpoint is located. You can only specify one ARN.
-
hasSecurityGroupArns
public final boolean hasSecurityGroupArns()For responses, this returns true if the service returned a value for the SecurityGroupArns property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
securityGroupArns
Specifies the Amazon Resource Name (ARN) of the security group that allows traffic between your agent and VPC service endpoint. You can only specify one ARN.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasSecurityGroupArns()method.- Returns:
- Specifies the Amazon Resource Name (ARN) of the security group that allows traffic between your agent and VPC service endpoint. You can only specify one ARN.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateAgentRequest.Builder,CreateAgentRequest> - Specified by:
toBuilderin classDataSyncRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-